Module index

Module index 

Code indexing engine: ast-grep based code parsing, symbol extraction, reference resolution, and incremental indexing.

Re-exports

pub use chunker::ChunkConfig;
pub use chunker::CodeChunk;
pub use indexer::IndexAndResolveResult;
pub use indexer::IndexProgress;
pub use indexer::IndexResult;
pub use indexer::Indexer;
pub use manifest::Dependency;
pub use manifest::ManifestResult;
pub use manifest::Workspace;
pub use parser::CodeParser;
pub use parser::ParseResult;
pub use resolver::ReferenceResolver;
pub use resolver::ResolvedEdge;
pub use symbol::Reference;
pub use symbol::ReferenceKind;
pub use symbol::Symbol;
pub use symbol::SymbolKind;
pub use symbol::Visibility;

Modules

chunker
CST-aware code chunking.
engine
Unified AST extraction engine using ast-grep.
incremental
SHA-256 based change detection for incremental indexing.
indexer
Main indexing pipeline orchestrator.
manifest
Manifest file parsing for cross-repo/cross-package dependency detection.
parser
ast-grep parsing coordinator.
resolver
Reference resolution into graph edges.
rule_loader
Compile-time YAML rule embedding and deserialization for per-language extraction rules.
symbol
Symbol and Reference types extracted from source code via tree-sitter.