pub fn detect_event_calls(
references: &[Reference],
symbols: &[Symbol],
) -> Vec<DetectedEventCall>Expand description
Detect event channel interactions from call references and symbol annotations.
pub fn detect_event_calls(
references: &[Reference],
symbols: &[Symbol],
) -> Vec<DetectedEventCall>Detect event channel interactions from call references and symbol annotations.