pub struct AstGrepEngine { /* private fields */ }Expand description
The unified extraction engine.
Implementations
Sourceimpl AstGrepEngine
impl AstGrepEngine
Sourcepub fn find_language(&self, ext: &str) -> Option<&LanguageRules>
pub fn find_language(&self, ext: &str) -> Option<&LanguageRules>
Look up the rules for a given file extension.
Sourcepub fn supports_extension(&self, ext: &str) -> bool
pub fn supports_extension(&self, ext: &str) -> bool
Check if a given extension is supported.
pub fn extract_symbols( &self, lang: &LanguageRules, source: &str, file_path: &str, ) -> Vec<Symbol>
Sourcepub fn extract_symbols_from_tree(
&self,
lang: &LanguageRules,
root: &AstGrep<StrDoc<SupportLang>>,
source: &str,
file_path: &str,
) -> Vec<Symbol>
pub fn extract_symbols_from_tree( &self, lang: &LanguageRules, root: &AstGrep<StrDoc<SupportLang>>, source: &str, file_path: &str, ) -> Vec<Symbol>
C1: Extract symbols from a pre-parsed AST tree, avoiding re-parsing.
Sourcepub fn extract_references(
&self,
lang: &LanguageRules,
source: &str,
file_path: &str,
) -> Vec<Reference>
pub fn extract_references( &self, lang: &LanguageRules, source: &str, file_path: &str, ) -> Vec<Reference>
Parse source code and extract references, deduplicating by (source_qualified_name, target_name, reference_kind).
Sourcepub fn extract_references_from_tree(
&self,
lang: &LanguageRules,
root: &AstGrep<StrDoc<SupportLang>>,
source: &str,
file_path: &str,
) -> Vec<Reference>
pub fn extract_references_from_tree( &self, lang: &LanguageRules, root: &AstGrep<StrDoc<SupportLang>>, source: &str, file_path: &str, ) -> Vec<Reference>
C1: Extract references from a pre-parsed AST tree, avoiding re-parsing.