Module graph_builder

Module graph_builder 

SCIP graph builder: create nodes + edges from parsed SCIP data.

Takes the intermediate structs from the reader and produces GraphNodes, Edges, and MemoryNodes (for hover documentation).

Structs

ScipBuildResult
Result of building graph structures from SCIP data.

Functions

build_graph
Build graph nodes, edges, and doc memories from a parsed SCIP result.