pub fn parse_asyncapi(path: &Path) -> Option<AsyncApiParseResult>Expand description
Parse an AsyncAPI (2.x / 3.0) spec file.
Returns None if the file cannot be read, is not valid JSON/YAML,
or lacks an asyncapi top-level key.
pub fn parse_asyncapi(path: &Path) -> Option<AsyncApiParseResult>Parse an AsyncAPI (2.x / 3.0) spec file.
Returns None if the file cannot be read, is not valid JSON/YAML,
or lacks an asyncapi top-level key.