pub fn parse_openapi(path: &Path) -> Option<SpecParseResult>Expand description
Parse an OpenAPI (2.0 Swagger / 3.x) spec file.
Returns None if the file cannot be read, is not valid JSON/YAML,
or lacks an openapi or swagger top-level key.
pub fn parse_openapi(path: &Path) -> Option<SpecParseResult>Parse an OpenAPI (2.0 Swagger / 3.x) spec file.
Returns None if the file cannot be read, is not valid JSON/YAML,
or lacks an openapi or swagger top-level key.