Module persistence

Module persistence 

Graph persistence: persist indexing results (file/package/symbol/chunk nodes, edges, embeddings, compaction) into the storage and graph backends.

Modules

cross_repo
Cross-repo persistence: register packages, store unresolved refs, run forward/backward linking, persist cross-namespace edges, and detect API endpoints.

Structs

CrossRepoPersistResult
Counts of what was persisted by persist_cross_repo_data.
IndexPersistResult
Counts of what was persisted by persist_index_results.

Functions

edge_weight_for
Return the edge weight for a given relationship type, using config overrides for the three most common types (Contains, Calls, Imports).