edge_weight_for

Function edge_weight_for 

pub fn edge_weight_for(rel: &RelationshipType, config: &GraphConfig) -> f64
Return the edge weight for a given relationship type, using config overrides for the three most common types (Contains, Calls, Imports).