pub struct EmbeddingService { /* private fields */ }Expand description
Embedding service with Candle inference (no internal cache — use CachedProvider wrapper).
Implementations
Sourceimpl EmbeddingService
impl EmbeddingService
Sourcepub fn new(
model_dir: &Path,
batch_size: usize,
) -> Result<EmbeddingService, CodememError>
pub fn new( model_dir: &Path, batch_size: usize, ) -> Result<EmbeddingService, CodememError>
Create a new embedding service, loading model from the given directory.
Expects model.safetensors, config.json, and tokenizer.json in the directory.
Sourcepub fn default_model_dir() -> PathBuf
pub fn default_model_dir() -> PathBuf
Get the default model directory path (~/.codemem/models/{MODEL_NAME}).
Sourcepub fn download_model(dest_dir: &Path) -> Result<PathBuf, CodememError>
pub fn download_model(dest_dir: &Path) -> Result<PathBuf, CodememError>
Download the model from HuggingFace Hub to the given directory. Returns the directory path. No-ops if model already exists.
Sourcepub fn embed(&self, text: &str) -> Result<Vec<f32>, CodememError>
pub fn embed(&self, text: &str) -> Result<Vec<f32>, CodememError>
Embed a single text string. Returns a 768-dim L2-normalized vector.
Sourcepub fn embed_batch(&self, texts: &[&str]) -> Result<Vec<Vec<f32>>, CodememError>
pub fn embed_batch(&self, texts: &[&str]) -> Result<Vec<Vec<f32>>, CodememError>
Embed a batch of texts using a true batched forward pass.
Tokenizes all texts, pads to the longest sequence in each chunk, runs a
single forward pass per chunk of up to batch_size texts, then performs
mean pooling and L2 normalization on the batched output.