pub struct FileWatcher { /* private fields */ }Expand description
File watcher that monitors a directory for changes with 50ms debouncing.
Implementations
Sourceimpl FileWatcher
impl FileWatcher
Sourcepub fn new(root: &Path) -> Result<Self, CodememError>
pub fn new(root: &Path) -> Result<Self, CodememError>
Create a new file watcher for the given root directory.
Sourcepub fn receiver(&self) -> &Receiver<WatchEvent>
pub fn receiver(&self) -> &Receiver<WatchEvent>
Get the receiver for watch events.