Module persistence

Module persistence 

Graph persistence: persist indexing results (file/package/symbol/chunk nodes, edges, embeddings, compaction) into the storage and graph backends.

Structs

IndexPersistResult
Counts of what was persisted by persist_index_results.

Functions

edge_weight_for
Return the edge weight for a given relationship type, using config overrides for the three most common types (Contains, Calls, Imports).