pub fn edge_weight_for(rel: &RelationshipType, config: &GraphConfig) -> f64Expand description
Return the edge weight for a given relationship type, using config overrides for the three most common types (Contains, Calls, Imports).
pub fn edge_weight_for(rel: &RelationshipType, config: &GraphConfig) -> f64Return the edge weight for a given relationship type, using config overrides for the three most common types (Contains, Calls, Imports).